/****************************************************************************
**
** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: openBossa - INdT (renato.chencarek@openbossa.org)
**
** $QT_BEGIN_LICENSE:LGPL$
** No Commercial Usage
** This file contains pre-release code and may not be distributed.
** You may use this file in accordance with the terms and conditions
** contained in the Technology Preview License Agreement accompanying
** this package.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** If you have questions regarding the use of this file, please contact
** the openBossa stream from INdT (renato.chencarek@openbossa.org).
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef DRAGGABLEPREVIEW_H
#define DRAGGABLEPREVIEW_H

#include <QGraphicsWidget>

QT_BEGIN_NAMESPACE
class QState;
class QAbstractAnimation;
QT_END_NAMESPACE


class DraggablePreview : public QGraphicsWidget
{
    Q_OBJECT

public:
    DraggablePreview(QGraphicsWidget *item, const QSize &screenSize,
                     QGraphicsItem *parent = 0);

signals:
    void draggableUpdate();
    void draggableStarted();
    void minimizeStarted();
    void maximizeStarted();
    void maximizeFinished();

protected:
    void mousePressEvent(QGraphicsSceneMouseEvent *e);
    void mouseMoveEvent(QGraphicsSceneMouseEvent *e);
    void mouseReleaseEvent(QGraphicsSceneMouseEvent *e);

private slots:
    void onMaximizeFinished();

private:
    void setupInterface();
    QAbstractAnimation *createAnimation(int time, const char *slot = 0);

    QGraphicsWidget *m_item;
    QSize m_screenSize;

    int m_border;
    int m_topMargin;
    int m_leftMargin;
    int m_maximizeRange;

    QPointF m_lastPos;
    QPointF m_draggablePos;
    int m_minimumOffset;
    int m_maximumOffset;

    QGraphicsPixmapItem *m_background;

    QState *m_minimizedState;
    QState *m_draggableState;
    QState *m_maximizedState;
};


#endif
